/**
 * React hook that is used to mark the block wrapper element.
 * It provides all the necessary props like the class name.
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-block-editor/#useBlockProps
 */
 import { useBlockProps } from '@wordpress/block-editor';
 import { RichText } from "@wordpress/block-editor";

 /**
  * The save function defines the way in which the different attributes should
  * be combined into the final markup, which is then serialized by the block
  * editor into `post_content`.
  *
  * @see https://developer.wordpress.org/block-editor/developers/block-api/block-edit-save/#save
  *
  * @param {Object} props            Properties passed to the function.
  * @param {Object} props.attributes Available block attributes.
  * @return {WPElement} Element to render.
  */
 export default function save( { attributes } ) {
    const { galleryTitle = "", images = [], imagesDescriptions = [], imagesCredits = [] } = attributes;

    const displayImages = (images) => {
        return (
            images.map((image, index) => {

                return (
                    <div className="gallery-item-container">
                        <img
                            className='gallery-item'
                            key={images.id}
                            src={image.url}
                            alt={image.alt}
                        />

                        <div class="image-meta">
                            <div class="image-description"> <RichText.Content tagName="span" value={imagesDescriptions[index]} /></div>
                            <i class="fas fa-camera"></i>
                            <div class="image-credit"> <RichText.Content tagName="span" value={imagesCredits[index]} /></div>
                        </div>

                    </div>
                )
            })
        )
    }

     return (
            <div className="image-gallery hacklab-block">
            <div className="image-gallery-wrapper">
                <div className="header">
                    <div className="gallery-title">
                        <RichText.Content tagName="h2" value={galleryTitle} />
                    </div>
                    <div className="actions">
                        <button action="display-grid">
                            <img src ="https://api.iconify.design/el/th.svg"/>
                        </button>

                        <button action="fullscreen">
                            <img class="open-fullscreen" src ="https://api.iconify.design/ant-design/fullscreen-outlined.svg"/>
                            <img class="close-fullscreen" src ="https://api.iconify.design/ant-design/fullscreen-exit-outlined.svg"/>
                        </button>
                    </div>
                </div>
                <div className="gallery-grid" data-total-slides={images.length}>
                    {displayImages(images)}
                </div>
            </div>
        </div>
    );
 }
