<?php
namespace hacklabBlocks;

/**
 * Flickr Album Gallery render_callback
 */
function flickr_album_gallery_callback( $attributes, $content, $block ) {

    $api_key = ( isset( $attributes['api_key'] ) && ! empty( $attributes['api_key'] ) ) ? esc_attr( $attributes['api_key'] ) : false;
    $album_id = ( isset( $attributes['album_id'] ) && ! empty( $attributes['album_id'] ) ) ? esc_attr( $attributes['album_id'] ) : false;

    if ( $api_key && $album_id ) {

        $gallery_title = ( isset( $attributes['gallery_title'] ) && ! empty( $attributes['gallery_title'] ) ) ? esc_attr( $attributes['gallery_title'] ) : false;

        $request_api = 'https://api.flickr.com/services/rest/?method=flickr.photosets.getPhotos&api_key=' . $api_key . '&photoset_id=' . $album_id . '&extras=url_m,url_o&format=json&nojsoncallback=1';
        $data = json_decode( file_get_contents( $request_api ) );

        $html = '<div class="wp-block-hacklab-flickr-album-gallery">';

        $html .= '<div class="flickr-album-gallery-header">';

            if ( $gallery_title ) {
                $html .= '<h2 class="underline">' . apply_filters( 'the_title', $gallery_title ) .  '</h2>';
            }

            $html .= '<div class="actions">';
            $html .= '<button action="display-grid"><img class="grid-activated" src="https://api.iconify.design/el/th.svg"/><img class="grid-deactivated" src="https://api.iconify.design/akar-icons/square.svg"/></button>';
            $html .= '<button action="fullscreen" data-fancybox-trigger="gallery"><img src="https://api.iconify.design/ant-design/expand-outlined.svg"/></button>';
            $html .= '</div>';

        $html .= '</div>';

        if ( isset( $data->stat ) && $data->stat == 'fail' ) {
            $html .= __( 'Failed to load images from Flickr.', 'flickr-album-gallery' );
        } else {
            $html .= '<div class="flickr-album-gallery-grid">';

                $html .= '<div class="flickr-album-gallery-buttons">';
                $html .= '<button class="hl-slider-back-btn">Back</button><button class="hl-slider-next-btn">Next</button>';
                $html .= '</div>';

                $html .= '<div class="flickr-album-gallery-container">';
                    $gallery = $data->photoset->photo;
                    foreach ( $gallery as $image ) {
                        $url_image = 'http://farm' . $image->farm . '.staticflickr.com/' . $image->server . '/' . $image->id . '_' . $image->secret . '.jpg';
                        $html .= '<a data-fancybox="gallery" class="hl-slide" href="' . esc_url( $url_image ) . '">';
                        $html .= '<div class="image" style="background-image: url(' . esc_url( $url_image ) . ');"></div>';
                        $html .= '</a>';
                    }
                $html .= '</div>';
            $html .= '</div>';
        }

        $html .= '</div>';

        return $html;
    }

    return '';

}

add_action( 'wp_enqueue_scripts', 'hacklabBlocks\\flickr_album_gallery_enqueue' );

function flickr_album_gallery_enqueue() {
    wp_enqueue_script( 'hl-slider', plugin_dir_url( __FILE__ ) . 'hl-slider.js', [], time(), true );
    wp_enqueue_style( 'fancybox', 'https://cdn.jsdelivr.net/npm/@fancyapps/ui/dist/fancybox.css', [], '1.0' );
    wp_enqueue_script( 'fancybox', 'https://cdn.jsdelivr.net/npm/@fancyapps/ui@4.0/dist/fancybox.umd.js', ['jquery'], '4.0', true );
}