import { __ } from '../../../assets/javascript/i18n';
import classNames from 'classnames'

import { useCallback, useState, useEffect, useMemo, useRef } from 'react'
import { language, countries, statesAndCities } from '../hooks/globals'

import Card from './Card.js'

import scrollIntoView from 'scroll-into-view'

const baseUrl = window.location.origin
const apiCacheVersion = window.geoInfoCacheVersion;

export default function List ({ _posts, title }) {

    const [stateUf, setStateUf] = useState(0);
    const [city, setCity] = useState(0);
    const [filterTermId, setFilterTermId] = useState([])
    const [organizations, setOrganizations] = useState([])
    const [posts, setPosts] = useState([])
    const [cities, setCities ] = useState(statesAndCities.filter( city => ( city.parent > 0 ) ) )


    //console.log( _posts );

    //setCities( 
    const setMapPositionByTerm = ( term ) => {
        window.CurrentJeoMap.map.flyTo({
            center: [
                term.meta._related_point[0]._geocode_lon,
                term.meta._related_point[0]._geocode_lat
            ],
            zoom: 5,
            bearing: 0,
            speed: 1,
            curve: 1,
        });

    }

    const setStateUfId = useCallback((e) => {
        setStateUf(Number(e.target.value))
        console.log( statesAndCities );
        setCities(statesAndCities.filter( city => ( city.parent > 0 && Number(e.target.value) == city.parent ) ))
        setMapPositionByTerm( statesAndCities.filter( term => ( term.id == Number(e.target.value) ) )[0] )
        setCity(0)
        console.log( e );
    }, [setStateUf])

    const setCityId = useCallback((e) => {
        setCity(Number(e.target.value))
        setMapPositionByTerm( statesAndCities.filter( term => ( term.id == Number(e.target.value) ) )[0] )

    }, [setCity])

    const setTermId = useCallback((e) => {
        setOrganizations([])
        setFilterTermId(city ? city : stateUf)
    }, [city, stateUf])

    const states = statesAndCities.filter( city => ( city.parent == 0 ) )
    
    const mountRef = useRef(true)

    const apiUrl = useMemo(() => {

        setOrganizations([])
        let url = ''
        

        url = new URL(`${baseUrl}/wp-json/wp/v2/estadoscidades/`)
    
        url.searchParams.set('apicv', apiCacheVersion)
        url.toString()
    
        return url

    }, [filterTermId])

    const apiUrlPosts = useMemo(() => {

        setPosts([])
        let url = ''
        

        url = new URL(`${baseUrl}/wp-json/wp/v2/testemunho/`)
    
        if (filterTermId && typeof filterTermId != 'object' ) {
            url.searchParams.set('estadoscidades', filterTermId)
        }
        url.searchParams.set('apicv', apiCacheVersion)
        url.toString()
    
        return url

    }, [filterTermId])
    useEffect(() => {
        setPosts(_posts.filter( post => ( typeof post.estadoscidades_names != 'undefined' ) ) )
    }, [_posts]);
    useEffect(() => {

        if (!mountRef.current) {

            const targetURL = new URL(`${ apiUrlPosts }`)
            const queryParams = { lang: language, per_page: 100 }

            Object.keys(queryParams).forEach(key => targetURL.searchParams.append(key, queryParams[key]))

            // Fetch posts based on params
            fetch(targetURL)
            .then( ( response ) => {
                return response.json()
            } )
            .then( data => {
                data = data.filter( post => ( typeof post.estadoscidades_names != 'undefined' ) )

                setPosts([...data ])
                return [...data ]
            })
            .catch( err => {
                console.log(err)
            })


        } 
        mountRef.current = false

    }, [ filterTermId ] )

    useEffect(() => {
        const targetURL = new URL(`${ apiUrl }`)
        const query = {};
        query.per_page = 100; // TODO handle limit of posts per query

        Object.keys(query).forEach(key => targetURL.searchParams.append(key, query[key]));
        targetURL.searchParams.append('lang', language);

        if ( typeof window.mapPopUp === 'object' ) {
            window.mapPopUp.remove();
        }

        fetch(targetURL)
            .then(async (response) => {
                const jsonResponse = await response.json();
                return { data: jsonResponse, totalPages: response.headers.get("x-wp-totalpages") };
            })
            .then(({ data, totalPages }) => {

                let mapEl = document.querySelector( '.jeomap' );

                if ( ! mapEl || ! window.jeomaps ) {
                    window.JeoInitMaps();
                }

                mapEl.style.display = 'block';

                if ( ! mapEl || ! mapEl.dataset || ! mapEl.dataset.uui_id ) {
                    return;
                }

                let JeoMap = window.jeomaps[ mapEl.dataset.uui_id ];
                window.CurrentJeoMap = window.jeomaps[ mapEl.dataset.uui_id ];

                // Save first page results
                let cumulativePosts = data.filter( (post) => post.meta._related_point != '' )
                cumulativePosts = cumulativePosts.map((post) => {
                    post.meta._related_point = JSON.parse( post.meta._related_point )
                    return post
                } )


                const buildRelatedPosts = (map) => {
                    map.resize();
                    if ( map.getSource( 'orgsSource') ) {
                        
                        map.removeLayer( 'unclustered-points');
                        map.removeLayer( 'hover-unclustered-points');
                        map.removeLayer( 'cluster-layer');
                        map.removeLayer( 'cluster-count');

                        map.removeImage( 'news-no-marker' );
                        map.removeImage( 'news-marker-hover' );
                        map.removeImage( 'news-marker' );
                        
                        map.removeSource( 'orgsSource'); 
                    }

                    let terms = []
                    for (let i = 0; i < cumulativePosts.length; i++) {
                        let element = cumulativePosts[i]
                        for (let counter = 1; element.count >= counter; counter++) {
                            if (element.parent > 0){
                                terms.push(element)
                            }
                        }

                    }
                    const sourceData = JeoMap.buildPostsGeoJson(terms);

                    map.addSource( 'orgsSource', {
                        type: 'geojson',
                        data: sourceData,
                        cluster: true,
                        clusterMaxZoom: 40,
                        clusterRadius: 40,
                    } );

                    map.loadImage(
                        window.directory_map.themeUrl + '/images/pin.png',
                        ( error, image ) => {
                            if ( error ) throw error;

                            map.addImage( 'news-marker', image );
                            // Single markers layer
                            map.addLayer( {
                                id: 'unclustered-points',
                                type: 'symbol',
                                source: 'orgsSource',
                                filter: [ '!', [ 'has', 'point_count' ] ],
                                layout: {
                                    'icon-image': 'news-marker',
                                    'icon-size': 1.1,
                                    'icon-allow-overlap': true,
                                    'text-field': '{count}',
                                    'text-font': ['Open Sans Bold', 'Arial Unicode MS Bold'],
                                    'text-size': 14,
                                    'text-transform': 'uppercase',
                                    'text-letter-spacing': 0.05,
                                    'text-offset': [0, 3],
                                    'text-ignore-placement':true,
                                    'text-anchor': 'center'
                                },

                                paint : {
                                    'text-color':'#FFFFFF',
                                    'text-translate':[0.1,-34],
                                }
                            } );

                            let open_marker = false;
                            map.on('click', 'unclustered-points', (e) => {
                                setStateUf( e.features[0].properties.parent )
                                setCity( e.features[0].properties.id )

                                setFilterTermId( e.features[0].properties.id )
                            });

                            map.loadImage(
                                window.directory_map.themeUrl + '/images/pin.png',
                                function ( error, image ) {
                                    if ( error ) throw error;

                                    map.addImage( 'news-marker-hover', image );

                                    map.addLayer( {
                                        id: 'hover-unclustered-points',
                                        type: 'symbol',
                                        source: 'orgsSource',
                                        filter: [ '!', [ 'has', 'point_count' ] ],
                                        layout: {
                                            'icon-image': 'news-marker-hover',
                                            'icon-size': 0.4,
                                            'icon-allow-overlap': true,
                                        },

                                        paint: {
                                            'icon-opacity': [
                                                'case',
                                                [ 'boolean', [ 'feature-state', 'hover' ], false ],
                                                1,
                                                0,
                                            ],
                                        },
                                    } );
                                }
                            );

                            map.loadImage( window.directory_map.themeUrl + '/images/pin.png' , (
                                error,
                                image
                            ) => {
                                if ( error ) throw error;

                                map.addImage( 'news-no-marker', image );

                                const layers = [
                                    // [6, '#000000'],
                                    // [5, '#f28cb1'],
                                    // [2, '#f1f075'],
                                    [ 0, '#ffffff' ],
                                ];

                                // cluster circle layer
                                layers.forEach( ( layer, i ) => {
                                    map.addLayer( {
                                        id: 'cluster-layer',
                                        type: 'circle',
                                        source: 'orgsSource',
                                        paint: {
                                            'circle-color': layer[ 1 ],
                                            'circle-opacity': 0,
                                            'circle-radius': 30 + layer[ 0 ],
                                            'circle-stroke-color': '#ffffff',
                                            'circle-stroke-opacity': 0,
                                            'circle-stroke-width': 20,
                                            'circle-translate':[0,-20],

                                        },
                                        filter:
                                            i === 0
                                                ? [ '>=', 'point_count', layer[ 0 ] ]
                                                : [
                                                        'all',
                                                        [ '>=', 'point_count', layer[ 0 ] ],
                                                        [ '<', 'point_count', layers[ i - 1 ][ 0 ] ],
                                                ],
                                    } );
                                } );

                                const flyIntoCluster = (map, coordinates) => {
                                    const maxZoom = 9;
                                                                    
                                    map.flyTo({
                                        center: coordinates,
                                        zoom: maxZoom,
                                        bearing: 0,
                                        speed: 1,
                                        curve: 1,
                                    });
                                
                                }

                                map.on('click', 'cluster-layer', function (e) {
                                    const features = map.queryRenderedFeatures(e.point, { layers: ['cluster-layer'] });
                                    const clusterId = features[0].properties.cluster_id
                                    const pointCount = features[0].properties.point_count
                                    const clusterSource = map.getSource('orgsSource');

                                    function multiDimensionalUnique(arr) {
                                        var uniques = [];
                                        var itemsFound = {};
                                        for(var i = 0, l = arr.length; i < l; i++) {
                                            var stringified = JSON.stringify(arr[i]);
                                            if(itemsFound[stringified]) { continue; }
                                            uniques.push(arr[i]);
                                            itemsFound[stringified] = true;
                                        }
                                        return uniques;
                                    }

                                    // Get all points under a cluster
                                    clusterSource.getClusterLeaves(clusterId, pointCount, 0, (err, aFeatures) => {
                                        const nextFeatures = multiDimensionalUnique(aFeatures.map( ( post ) => post.geometry.coordinates.map(val => parseFloat(val))));

                                        if(nextFeatures.length >= 2) {
                                            map.fitBounds([
                                                ...nextFeatures
                                            ], { padding: 300});

                                            setStateUf( aFeatures[0].properties.parent )
                                            setFilterTermId( aFeatures[0].properties.parent )
                    
                                        } else {
                                            setStateUf( aFeatures[0].properties.parent )
                                            setCity( aFeatures[0].properties.id )

                                            setFilterTermId( aFeatures[0].properties.id )
                                        }
                                    })

                                    flyIntoCluster(JeoMap.map, features[0].geometry.coordinates, JeoMap.map.getZoom());

                                })

                                // cluster number layer
                                 map.addLayer( {
                                    id: 'cluster-count',
                                    type: 'symbol',
                                    source: 'orgsSource',

                                    layout: {
                                        'icon-image': 'news-marker',
                                        'icon-size': 0.9,
                                        'icon-allow-overlap': true,
                                        'text-field': '{point_count}',
                                        'text-font': ['Open Sans Bold', 'Arial Unicode MS Bold'],
                                        'text-size': 14,
                                        'text-transform': 'uppercase',
                                        'text-letter-spacing': 0.05,
                                        'text-offset': [0, 3],
                                        'text-ignore-placement':true,
                                        'text-anchor': 'center'
                                    },
                                    paint:{
                                        'text-color':'#FFFFFF',
                                        'text-translate':[0.1,-74],
                                        'icon-translate':[0,-43],
                                    },

                                    filter: [ 'has', 'point_count' ],
                                } );

                             } );
                        }
                    );

                    // Keep requesting to get to the last page
                    for (let i = 2; i <= totalPages; i++) {
                        // Break to avoid respect page limiting
                        if (i >= 100) {
                            break;
                        }

                        targetURL.searchParams.set('page', i);

                        fetch(targetURL)
                            .then(response => { return response.json() })
                            .then(moreresults => {
                                cumulativePosts = [...cumulativePosts, ...moreresults];


                                const sourceData = JeoMap.buildPostsGeoJson(cumulativePosts);
                                map.getSource('orgsSource').setData(sourceData);
                            });
                    }

                }

                // if(this.map.loaded()) {
                // 	console.log("Map loaded")
                if ( JeoMap.map.loaded() ) {
                    buildRelatedPosts(JeoMap.map)
                } else {
                    JeoMap.map.on( 'load', () => {
                        buildRelatedPosts(JeoMap.map)

                        JeoMap.map.on('mouseenter', 'cluster-layer', (e) => {
                            JeoMap.map.getCanvas().style.cursor = 'pointer';
                        });
                        
                        // Change the cursor back to a pointer
                        // when it leaves the states layer.
                        JeoMap.map.on('mouseleave', 'cluster-layer', () => {
                            JeoMap.map.getCanvas().style.cursor = '';
                        });

                        JeoMap.map.on('mouseenter', 'unclustered-points', (e) => {
                            JeoMap.map.getCanvas().style.cursor = 'pointer';
                        });
                        
                        // Change the cursor back to a pointer
                        // when it leaves the states layer.
                        JeoMap.map.on('mouseleave', 'unclustered-points', () => {
                            JeoMap.map.getCanvas().style.cursor = '';
                        });

                    });
                }
                // } else {
                    // console.log("Load event")
                    // this.map.on( 'load', () => {
                        // console.log("Load event confirmed")
                        // buildRelatedPosts(this.map)
                    // })
                // }
        })
    }, [] )

    let titleFilters = title

    return (
        <>
            <div className="organizations">

                <h2>{ __('Filter locations or click on a map marker', 'hacklab-blocks') }</h2>

                <div className="organizations-filters">
                    <header>
                        <h2>{ titleFilters }</h2>
                    </header>

                    <section>
                        <div className="state-filter">
                            <form>
                                <label>
                                    <div className="select-wrapper">
                                        <select value={ stateUf } onChange={ setStateUfId }>
                                            <option key={ 0 } value={ 0 }>{ __('Select a State', 'hacklab-blocks') }</option>
                                            { states.map(item => (
                                                <option key={ item.id } value={ item.id }>{ item.name }</option>
                                            )) }
                                        </select>
                                    </div>
                                </label>
                            </form>
                        </div>

                        <div className="city-filter">
                            <form>
                                <label>
                                    <div className="select-wrapper">
                                        <select value={ city } onChange={ setCityId }>
                                            <option key={ 0 } value={ 0 }>{ __('Select a City', 'hacklab-blocks') }</option>
                                            { cities.map(item => (

                                                <option key={ item.id } value={ item.id }>{ item.name }</option>
                                            )) }
                                        </select>
                                    </div>
                                </label>
                            </form>
                        </div>

                        <button onClick={setTermId}>{ __('Filter', 'hacklab-blocks') }</button>
                    </section>

                    <ul className="directory-article--list">
                    {
                        posts.length > 0 ?
                            posts.map( ({ id, title, content, meta, estadoscidades_names, link }) => (
                                <Card title={ title.rendered } content={ content.rendered } meta={meta} estadoscidades={estadoscidades_names} link={ link }/>
                            ) )
                        : <p className="not-found-organization"> { __('No testimonials found', 'hacklab-blocks') } </p>

                    }
                    </ul>

                </div>

            </div>

        </>
    )
}

/* document.querySelector( '#page' ).addEventListener( 'click' , (e) => {
    if ( ! e.target.tagName === 'BUTTON' || ! e.target.classList.contains( 'mapboxgl-popup-close-button' ) ) {
        return;
    }
    if ( document.querySelector( '.directory-article--list li.selected' ) ) {
        if ( typeof window.mapPopUp === 'object' ) {
            window.mapPopUp.remove();
        }
        document.querySelector( '.directory-article--list li.selected' ).classList.remove( 'selected' );
    }
}); */