<?php
namespace hacklabBlocks;

/**
 * Geo information render_callback
 */
function geo_information_callback( $attributes, $content, $block ) {
	$content = wp_strip_all_tags( $content );
	
    return "<div class='wp-block-hacklab-geo-information'>
        <div class='each-hacklab-geo-information' data-title='{$content}'>Loading..</div>
    </div>";

}
function filter_term_response( $data, $post, $context ){

    // Does this have categories?
    if( !empty($data->data['estadoscidades']) ){

        // Loop through them all
		$data->data['estadoscidades_names'] = array();
        foreach( $data->data['estadoscidades'] as $term_id ){
            // Get the actual Category Object
            $term = get_term( $term_id, 'estadoscidades' );

            if( $term->parent == 0 ){
                $data->data['estadoscidades_names']['estadoscidades_state'] = $term->name;
            } else {
                // some child level category
                $data->data['estadoscidades_names']['estadoscidades_city'] = $term->name;
            }
        }
    }

    return $data;
}
add_filter( 'rest_prepare_testemunho', 'hacklabBlocks\\filter_term_response', 10, 3 );
/**
* Register JEO scripts.
*/
function register_jeo_assets() {
    wp_enqueue_style( 'mapboxgl', 'https://api.mapbox.com/mapbox-gl-js/v1.4.1/mapbox-gl.css', '1.4.1' );

    wp_register_script( 'mapboxgl-loader', JEO_BASEURL . '/js/build/mapboxglLoader.js', JEO_VERSION );

    wp_register_script( 'jeo-map', JEO_BASEURL . '/js/build/jeoMap.js', [ 'mapboxgl-loader', 'jquery', 'wp-element' ], JEO_VERSION, true );
    wp_localize_script( 'jeo-map', 'jeoMapVars', [
        'jsonUrl' => rest_url( 'wp/v2/' ),
        'jeoUrl' => JEO_BASEURL,
        'nonce' => wp_create_nonce( 'wp_rest' ),
        'templates' => [
        	'moreInfo' => file_get_contents( jeo_get_template( 'map-more-info.ejs' ) ),
        	'popup' => file_get_contents( jeo_get_template( 'generic-popup.ejs' ) ),
        	'postPopup' => file_get_contents( jeo_get_template( 'post-popup.ejs' ) )
        ],
        'cluster' => apply_filters( 'jeomap_js_cluster', [
            'circle_color' => '#ffffff'
        ] ),
        'images' => apply_filters( 'jeomap_js_images', [
            '/js/src/icons/news-marker' => [
                'url' => JEO_BASEURL . '/js/src/icons/news-marker.png',
                'icon_size' => 0.1,
            ],
            '/js/src/icons/news-marker-hover' => [
                'url' => JEO_BASEURL . '/js/src/icons/news-marker-hover.png',
                'icon_size' => 0.1,
            ],
            '/js/src/icons/news' => [
                'url' => JEO_BASEURL . '/js/src/icons/news.png',
                'icon_size' => 0.13,
            ],
        ] )
    ] );

	wp_register_script(
		'mapboxgl-spiderifier',
		JEO_BASEURL . '/js/src/mapboxgl-spiderifier/index.js',
		'mapboxgl-loader',
		null,
		false
	);

    wp_register_script( 'jeo-layer', JEO_BASEURL . '/js/build/JeoLayer.js', [ 'mapboxgl-loader' ], JEO_VERSION );
    wp_register_script( 'layer-type-mapbox', JEO_BASEURL . '/includes/layer-types/mapbox.js', [ 'jeo-layer' ], JEO_VERSION );

	wp_register_script( 'jeo-legend', JEO_BASEURL . '/js/build/JeoLegend.js', [ 'mapboxgl-loader' ], JEO_VERSION );
	wp_enqueue_script( 'mapboxgl-spiderifier' );

	wp_enqueue_script( 'jeo-map' );
	wp_enqueue_script( 'jeo-layer' );
	wp_enqueue_script( 'layer-type-mapbox' );
	wp_enqueue_script( 'jeo-legend' );


}
function save_state_geocode( $state ) {
	$url = "https://nominatim.openstreetmap.org/search?state={$state->name}&format=json";
	$response = wp_remote_get( $url, array() );
	if ( is_wp_error( $response ) || 200 != $response[ 'response']['code'] ) {
		return;
	}
	$geo_response = json_decode( $response[ 'body' ], true );
	$geo_response[0][ '_geocode_lon'] = $geo_response[0][ 'lon'];
	$geo_response[0][ '_geocode_lat'] = $geo_response[0][ 'lat'];

	update_term_meta( $state->term_id, '_related_point', json_encode( array( $geo_response[0] ) ) );

}
add_action( 'saved_estadoscidades' , function( $term_id ){
	$term = get_term( $term_id, 'estadoscidades' );
	if( $term->parent == 0 ) {
		save_state_geocode( $term );
		return;
	}
	$state = get_term( $term->parent, 'estadoscidades' );
	$url = "https://nominatim.openstreetmap.org/search?state={$state->name}&city={$term->name}&format=json";
	$response = wp_remote_get( $url, array() );
	if ( is_wp_error( $response ) || 200 != $response[ 'response']['code'] ) {
		return;
	}
	$geo_response = json_decode( $response[ 'body' ], true );
	$geo_response[0][ '_geocode_lon'] = $geo_response[0][ 'lon'];
	$geo_response[0][ '_geocode_lat'] = $geo_response[0][ 'lat'];

	update_term_meta( $term_id, '_related_point', json_encode( array( $geo_response[0] ) ) );

}, 10, 1);

function register_geo_term_meta() {
	$object_type = 'term'; // The object type. 
	
	$args = array(
		'object_subtype' => 'estadoscidades',
    	'type'      => 'string', // Validate and sanitize the meta value as a string.
        	// Default: 'string'.  
        	// In 4.7 one of 'string', 'boolean', 'integer', 'number' must be used as 'type'. 
    	'description'    => 'A meta key associated with a string meta value.', // Shown in the schema for the meta key.
    	'single'        => true, // Return a single value of the type. Default: false.
    	'show_in_rest'    => true, // Show in the WP REST API response. Default: false.
	);
	
	register_meta( $object_type, '_related_point', $args );

}
register_geo_term_meta();

add_action( 'wp_enqueue_scripts', function(){
    global $wp;
    $block_name = 'hacklab-blocks/geo-information';
    $plugin_folder_url = HACKLAB_BLOCKS_PATH_URL;
    $js_file_path = plugin_dir_path(__FILE__) . 'front.js';
    $handle = 'geo_information_front_script';

    
    if( has_block( $block_name ) && defined( 'JEO_VERSION' )) {
		register_jeo_assets();

        $block_json_data = json_decode( file_get_contents(plugin_dir_path(__FILE__) . 'block.json') );

        wp_enqueue_script( $handle, $plugin_folder_url . 'build/js/geo-information-front/geo-information-front.js', array('react', 'react-dom', 'wp-element', 'wp-i18n'), filemtime( $js_file_path ) );
       	wp_localize_script($handle,'geoInfoCacheVersion', [$block_json_data->version] );

		wp_localize_script( $handle, 'hacklabBlocks', [
			'i18n' => [
				'__' => [
					'City: ' => __( 'City: ', 'hacklab-blocks' ),
					'Filter locations or click on a map marker' => __( 'Filter locations or click on a map marker', 'hacklab-blocks' ),
					'Filter' => __( 'Filter', 'hacklab-blocks' ),
					'No testimonials found' => __( 'No testimonials found', 'hacklab-blocks' ),
					'Read More' => __( 'Read More', 'hacklab-blocks' ),
					'Select a City' => __( 'Select a City', 'hacklab-blocks' ),
					'Select a State' => __( 'Select a State', 'hacklab-blocks' ),
					'State: ' => __( 'State: ', 'hacklab-blocks' ),
					'Testimonial: ' => __( 'Testimonial: ', 'hacklab-blocks' ),
				]
			]
		]);

        $maps = get_posts(['post_type' => 'map', 'post_status' => 'publish']);
		$map_id = empty($maps) ? 0 : $maps[0]->ID;

		wp_localize_script($handle, 'directory_map', array(
			'map_id' => $map_id,
			'themeUrl' => apply_filters( 'hacklab_blocks_geo_information_theme_url', "{$plugin_folder_url}/blocks/geo-information" )
		));
		$sortTermsBySlug = function ($a, $b) {
			return (int) decbin( ord( $a->slug ) ) - (int) decbin( ord( $b->slug ) );
		};

		function get_term_wpml( $id ) {
			$all_langs = icl_get_languages('skip_missing=0');
		 
			$current_id = array();
			foreach( (array)$all_langs as $lang ) {
				$current_id[$lang['language_code']] = icl_object_id( $id, 'pais', false, $lang['language_code'] );
			}
			 
			return $current_id;
		}

        $queryTaxonomy = function ($taxonomy, $sortFn, $fields = []) {
			$args = [
				'hide_empty' => true,
				'taxonomy' => $taxonomy,
			];

			$query = get_terms($args);
			usort($query, $sortFn);
			$terms = [];
			foreach ($query as $term) {
				$language_mapping = get_term_wpml($term->term_id);
				// echo $term->name;
				// var_dump($language_mapping);

				$termId = $term->term_id;
				$meta = get_term_meta( $termId);
				if( isset( $meta[ '_related_point'] ) ) {
					$meta[ '_related_point' ] = json_decode( $meta[ '_related_point' ][0] );
				}
				$term = [
					'id' => $termId,
					'description' => $term->description,
					'name' => $term->name,
					'parent' => $term->parent,
					'slug' => $term->slug,
					'languageMap' => $language_mapping,
					'meta'		=> $meta
				];
				foreach ($fields as $key => $field) {
					if(is_array($field)) {
						$term[$key] = get_term_meta($termId, $field[0], false);
					} else {
						$term[$key] = get_term_meta($termId, $field, true);
					}
				}
				$terms[] = $term;
			}
			return $terms;
		};

		$currentRequestArgs = [
			'per_page' => 8,
		];

		$validFor = 0;

        $request = new \WP_REST_Request( 'GET', '/wp/v2/testemunho' );
		$request->set_query_params( $currentRequestArgs );
		$response = rest_do_request( $request );
		$server = rest_get_server();
		$data = $server->response_to_data( $response, false );

		$initialRequestPosts = [
			'posts' => $data,
			'totalPages' => $response->headers["X-WP-TotalPages"],
			'total' => $response->headers["X-WP-Total"],
			'validFor' =>  $validFor,
		];

		global $sitepress;

		wp_localize_script($handle, 'DirectoryData', [
			'statesAndCities' => $queryTaxonomy('estadoscidades', $sortTermsBySlug, [] ),
			'defaultLanguage' => isset($sitepress)? $sitepress->get_default_language() : '',
			'directoryUrl' => home_url( $wp->request ),
			'initialRequestPosts' => $initialRequestPosts,
			'language' => ICL_LANGUAGE_CODE,
		]);
    }

}, 10 );