import { __ } from '@wordpress/i18n'
import { useBlockProps, InspectorControls } from '@wordpress/block-editor'
import { Disabled, PanelBody, SelectControl, TextControl, ToggleControl } from '@wordpress/components'
import { __experimentalNumberControl as NumberControl } from '@wordpress/components'
import { useEffect, useState } from '@wordpress/element'
import apiFetch from '@wordpress/api-fetch'
import ServerSideRender from '@wordpress/server-side-render'

const edit = ({ attributes, setAttributes }) => {
	const { cardLayout, selectedSite, taxonomySlug, termSlug, postsBySite, showDate, totalPosts, useSlider } = attributes
	const [sites, setSites] = useState([]);

	useEffect(() => {
		apiFetch({ path: '/wp/v2/sites' }).then((sites) => {
			setSites(sites)
		})
	}, [])

	const updateSelectedSite = (site) => {
		setAttributes({ selectedSite: site })
	};

	const updateTaxonomySlug = (slug) => {
		setAttributes({ taxonomySlug: slug })
	}

	const updateTermSlug = (slug) => {
		setAttributes({ termSlug: slug })
	}

	const updatePostsBySite = (qty) => {
		setAttributes({ postsBySite: qty })
	}

	const updateShowDate = (use) => {
		setAttributes({ showDate: use })
	}

	const updateTotalPosts = (qty) => {
		setAttributes({ totalPosts: qty })
	}

	const updateCardLayput = (style) => {
		setAttributes({ cardLayout: style })
	}

	const updateUseSlider = (use) => {
		setAttributes({ useSlider: use })
	}

	return (
		<div {...useBlockProps()}>
			<InspectorControls>
				<PanelBody title={ __('Configurações', 'base-textdomain') }>
					<SelectControl
						label={ __('Selecione um ou todos os sites', 'base-textdomain') }
						value={ selectedSite }
						options={[
							{
								value: '',
								label: __('Selecione o site', 'base-textdomain')
							},
							{
								value: sites.map(site => site.blog_id).join(','),
								label: __('Todos os sites', 'base-textdomain')
							},
							...sites.map((site) => ({
								value: site.blog_id,
								label: site.domain + site.path
							})),
						]}
						onChange={ updateSelectedSite }
					/>
					<TextControl
						label={ __('Slug da taxonomia', 'base-textdomain') }
						value={ taxonomySlug }
						onChange={updateTaxonomySlug}
					/>
					<TextControl
						label={ __('Slug do termo da categoria', 'base-textdomain') }
						value={ termSlug }
						onChange={ updateTermSlug }
					/>
					<NumberControl
						label={ __('Quantidade de posts para cada site', 'base-textdomain') }
						isShiftStepEnabled={ true }
						onChange={ updatePostsBySite }
						shiftStep={ 1 }
						value={ postsBySite }
					/>
					<NumberControl
						label={ __('Total geral de posts', 'base-textdomain') }
						isShiftStepEnabled={ true }
						onChange={ updateTotalPosts }
						shiftStep={ 1 }
						value={ totalPosts }
					/>

					<ToggleControl
						label={ __('Exibir data', 'base-textdomain') }
						checked={ showDate }
						onChange={ updateShowDate }
					/>

					<ToggleControl
						label={ __('Usar slider', 'base-textdomain') }
						checked={ useSlider }
						onChange={ updateUseSlider }
					/>

					{ ! useSlider &&
						<SelectControl
							label={ __('Modelo do card', 'base-textdomain') }
							value={ cardLayout }
							options={[
								{ label: __('Card sem imagem', 'base-textdomain'), value: 'card-without-thumb' },
								{ label: __('Card vertical e com thumbnail', 'base-textdomain'), value: 'card-thumb-vertical' },
								{ label: __('Card horizontal e com thumbnail', 'base-textdomain'), value: 'card-thumb-horizontal' }
							]}
							onChange={ updateCardLayput }
						/>
					}
				</PanelBody>
			</InspectorControls>
			<div>
				<Disabled>
					<ServerSideRender
						block="hacklab-blocks/posts-by-network"
						attributes={ attributes }
					/>
				</Disabled>
			</div>
		</div>
	);
};

export default edit;
