<?php

namespace hacklabBlocks;

require __DIR__ . '/library/index.php';

function posts_by_network_callback( $attributes, $content, $block ) {

	global $wpdb;

	$selected_site = ( isset( $attributes['selectedSite'] ) && ! empty( $attributes['selectedSite'] ) ) ? esc_attr( $attributes['selectedSite'] ) : '';

	if ( ! empty( $selected_site ) ) {
		if ( ! is_array( $selected_site ) ) {
			$selected_site = explode( ',', $selected_site );
		}
	}

	$post_type_slug = ( isset( $attributes['postTypeSlug'] ) && ! empty( $attributes['postTypeSlug'] ) ) ? sanitize_title( $attributes['postTypeSlug'] ) : 'post';
	$taxonomy_slug  = ( isset( $attributes['taxonomySlug'] ) && ! empty( $attributes['taxonomySlug'] ) ) ? sanitize_title( $attributes['taxonomySlug'] ) : '';
	$term_slug      = ( isset( $attributes['termSlug'] ) && ! empty( $attributes['termSlug'] ) ) ? sanitize_title( $attributes['termSlug'] ) : '';
	$posts_by_site  = ( isset( $attributes['postsBySite'] ) && ! empty( $attributes['postsBySite'] ) ) ? sanitize_title( $attributes['postsBySite'] ) : 2;
	$show_date      = ( isset( $attributes['showDate'] ) && ! empty( $attributes['showDate'] ) ) ? sanitize_title( $attributes['showDate'] ) : false;
	$total_posts    = ( isset( $attributes['totalPosts'] ) && ! empty( $attributes['totalPosts'] ) ) ? sanitize_title( $attributes['totalPosts'] ) : 10;
	$use_slider     = ( isset( $attributes['useSlider'] ) && ! empty( $attributes['useSlider'] ) ) ? sanitize_title( $attributes['useSlider'] ) : false;
	$card_layout    = ( isset( $attributes['cardLayout'] ) && ! empty( $attributes['cardLayout'] ) ) ? sanitize_title( $attributes['cardLayout'] ) : 'card-thumb-horizontal';

	if ( is_array( $selected_site ) ) {
		$sites = get_sites( ['site__in' => $selected_site] );
	} else {
		$sites = get_sites();
	}

	$should_break = false;
	$counter      = 0;

	ob_start();

	$all_posts = array();

	$container_class = $use_slider ? 'block-posts-by-network posts-by-network-slider' : 'block-posts-by-network';

	echo '<div class="' . $container_class . '">';

		if ( $use_slider ) :
			$card_layout = 'card-thumb-vertical';
			echo '<div class="items">';
		endif;

		foreach ( $sites as $site ) {
			if ( $should_break ) {
				break;
			}

			switch_to_blog( $site->blog_id );

			$tableName              = $wpdb->prefix . 'posts';
			$termTaxonomyTable      = $wpdb->prefix . 'term_taxonomy';
			$termRelationshipsTable = $wpdb->prefix . 'term_relationships';

			$query = "SELECT DISTINCT p.* FROM $tableName AS p";

			if ( ! empty( $taxonomy_slug ) && ! empty( $term_slug ) ) {
				$query .= " INNER JOIN $termRelationshipsTable AS tr ON p.ID = tr.object_id";
				$query .= " INNER JOIN $termTaxonomyTable AS tt ON tr.term_taxonomy_id = tt.term_taxonomy_id";
				$query .= " INNER JOIN $wpdb->terms AS t ON tt.term_id = t.term_id";
				$query .= $wpdb->prepare( " WHERE p.post_type = %s AND p.post_status = 'publish' AND tt.taxonomy = %s AND t.slug = %s", $post_type_slug, $taxonomy_slug, $term_slug );
			} else {
				$query .= $wpdb->prepare( " WHERE p.post_type = %s AND p.post_status = 'publish'", $post_type_slug );
			}

			$query .= " ORDER BY p.post_date DESC LIMIT %d";
			$final_query = $wpdb->prepare( $query, $posts_by_site );

			$latest_posts = $wpdb->get_results( $final_query );

			if ( ! empty( $latest_posts ) ) {
				foreach ( $latest_posts as $post_data ) {
					$counter++;

					$data = [
						'blog_id'       => $site->blog_id,
						'counter'       => $counter,
						'post_data'     => $post_data,
						'show_taxonomy' => $taxonomy_slug,
						'show_date'     => $show_date
					];

					$all_posts[] = $data;

					if ( $counter >= $total_posts ) {
						$should_break = true;
						break;
					}
				}
			}

			restore_current_blog();
		}

		usort( $all_posts, function( $a, $b ) {
			return strtotime( $b['post_data']->post_date ) - strtotime( $a['post_data']->post_date );
		});

		foreach($all_posts as $post_data){
			load_template_part( $card_layout, $post_data);
		}

		if ( $use_slider ) :
			echo '</div>';
		endif;

		if ( ! $counter ) {
			echo '<h3>' . __( 'Nenhum conteúdo encontrado.', 'hacklab-blocks' ) . '</h3>';
		}

	echo '</div>';

	$output = ob_get_clean();

	return $output;
}
