<?php
switch_to_blog( $blog_id );

$taxonomy = $show_taxonomy ? $show_taxonomy : 'category';
$terms    = get_the_terms( $post_data, $taxonomy );
$terms    = apply_filters( 'posts_by_network_list_of_terms', $terms, $post_data->ID, $taxonomy );

$post_author = get_userdata( $post_data->post_author );

if ( $post_author ) {
	$post_author = $post_author->display_name;
	$post_author = "<span class='author'>$post_author</span>";
}

/**
 * Filter on HTML author
 */
$post_author = apply_filters( 'posts_by_network_list_of_authors', $post_author, $post_data, $blog_id );

$post_date   = $post_data->post_date;
$date_format = get_option( 'date_format' );
$timestamp   = strtotime( $post_date );
$post_date   = date_i18n( $date_format, $timestamp );

/**
 * Filter the date output
 */
$date = apply_filters( 'posts_by_network_date_output', $post_date );

$credit_text = get_post_meta( get_post_thumbnail_id( $post_data ), '_credit_text', true );
?>

<div class="card card-thumb-horizontal post-id-<?php echo $post_data->ID; ?> counter-<?php echo $counter; ?> blog-id-<?php echo $blog_id; ?>">
	<?php if ( has_post_thumbnail( $post_data->ID ) ) : ?>
		<div class="thumbnail-wrap">
			<div class="thumbnail">
				<a href="<?php echo get_permalink( $post_data->ID ); ?>">
					<div class="aspect-ratio">
						<?php echo get_the_post_thumbnail( $post_data->ID, 'medium' ); ?>
					</div>
				</a>
			</div>

			<?php if ( $credit_text ) : ?>
				<div class="thumbnail-credit">
					<span><?php echo __( 'foto: ', 'base-textdomain' ) . ' ' . esc_attr( $credit_text ); ?></span>
				</div>
			<?php endif; ?>
		</div>
	<?php endif; ?>

	<div class="content">
		<?php if ( $terms && is_array( $terms ) ) : ?>
			<div class="meta">
				<ul class="list-terms tax-<?php echo sanitize_title( $taxonomy ); ?>">
					<?php foreach ( $terms as $term ) : ?>
						<li class="term-<?php echo sanitize_title( $term->slug ); ?>">
							<a href="<?php echo esc_url( get_term_link( $term->term_id ) ); ?>">
								<?php echo esc_attr( $term->name ); ?>
							</a>
						</li>
					<?php endforeach; ?>
				</ul>
			</div>
		<?php endif; ?>

		<div class="title">
			<h2>
				<a href="<?php echo get_permalink( $post_data->ID ); ?>">
					<?php echo esc_html( $post_data->post_title ); ?>
				</a>
			</h2>
		</div>

		<?php if ( $post_author ) : ?>
			<div class="authors">
				<?php echo $post_author; ?>
			</div>
		<?php endif; ?>

		<?php if ( $show_date && $date ) : ?>
			<div class="date">
				<span><?php echo $date; ?></span>
			</div>
		<?php endif; ?>
	</div>
</div>

<?php
restore_current_blog();