<?php
namespace hacklabBlocks;

function is_empty_recursive( $data ) {
	if ( is_array( $data ) ) {
		$filteredData = array_filter( $data, function ( $item ) {
			return is_array( $item ) ? !empty( array_filter( $item ) ) : !empty( $item );
		});

		if ( empty( $filteredData ) ) {
			return true;
		} else {
			return false;
		}
	}
}

if ( ! function_exists( 'hacklabBlocks\\extract_base_url' ) ) {
	/**
	 * Helper to get base url
	 */
	function extract_base_url( $url ) {
		$parsed_url = parse_url( $url );

		if ( $parsed_url === false ) {
			return false;
		}

		$base_url = $parsed_url['scheme'] . '://' . $parsed_url['host'];

		if ( isset( $parsed_url['port'] ) && ( ( $parsed_url['scheme'] === 'http' && $parsed_url['port'] !== 80 ) || ( $parsed_url['scheme'] === 'https' && $parsed_url['port'] !== 443 ) ) ) {
			$base_url .= ':' . $parsed_url['port'];
		}

		return $base_url;
	}
}

if ( ! function_exists( 'hacklabBlocks\\get_user_from_api' ) ) {
	/**
	 * Helper to get user from WP API
	 */
	function get_user_from_api( $api_url, $user_id ) {

		$url = "{$api_url}/{$user_id}";

		$response = wp_remote_get( $url );

		if ( is_wp_error( $response ) ) {
			do_action( 'qm/debug', ['Message' => $response->get_error_message()] );
			return false;
		}

		$response_data = wp_remote_retrieve_body( $response );
		$user_data = json_decode( $response_data );

		if ( is_object( $user_data ) && isset( $user_data->code ) && $user_data->code === 'rest_user_invalid_id' ) {
			do_action( 'qm/debug', ['Message' => $user_data->message, 'Status' => $user_data->data->status] );
			return false;
		}

		return $user_data;
	}
}
